PCB Environment: Data Fields

PCB Environment 2

Loading...
Searching...
No Matches
Here is a list of all struct and union fields with links to the structures/unions they belong to:

### - c -

- C : CloneEnv, UIActions
- CacheRef : Action
- calcNumPoints3D() : UniformGrid25
- Camera() : Camera
- can_route : dsn::Placement
- canAddVia() : NavPoint
- canAddViaEver() : NavPoint
- canAttach() : Track
- canDrawAsTriFan() : AShape, CircleEx, PolygonEx, WideSegment_25
- canPlaceVia() : NavPoint
- canPlaceViaEver() : NavPoint
- canPlaceViasInside() : Object
- canRoute() : NavPoint
- canRouteInside() : Object
- canRouteOnLayer() : Connection
- centroid() : AShape, CircleEx, IsoRectEx, PolygonEx, TriangleEx, WideSegment_25
- Chan : NavPixel< chan_t >
- checkAPI() : py::NPArray< T >
- checkBracket() : DSNParserBase
- checkFit() : NavImage< chan_t >
- checkPinIntersections() : PCBFactory
- checkQuote() : DSNParserBase
- checkRasterization() : Connection, Track
- checkRouted() : Connection
- checkType() : py::NPArray< T >
- CircleEx() : CircleEx
- Class : Policy::CommonParams
- classTypenum() : py::NPArray< T >
- clear() : ActionCache< Data >, ActionSet, ActionSpace, ParameterTab, Path, PCBItemSets, RoutePainter, Track
- Clearance : NavSpacings, UserAgent
- clearance() : Connection, dsn::Connection, dsn::Net, dsn::Pin, dsn::Placement, dsn::Structure, NetOverrides
- clearCache() : Action
- clearFlags() : NavPoint
- clearTracks() : Connection
- clone() : AShape, CircleEx, Component, Connection, IsoRectEx, Net, Object, PCBoard, Pin, PolygonEx, TriangleEx, WideSegment_25
- CloneEnv() : CloneEnv
- close() : Env, EnvPCB
- Color() : Color
- colorFill() : Pin
- colorLine() : Pin
- compare() : Path
- complement() : PCBItemSets
- Component() : Component
- compound : dsn::Pin, Pin
- computeLength() : Path, Track
- computeRMSD() : Path
- computeWinding() : Path
- coms : PCBItemSets
- Connect : UserAgent
- connect() : ActionTab, BrowserTab, UIActions
- Connection() : Connection
- connection() : Net
- Connections : NetTopology
- connections : dsn::Net, Net, Pin
- connectivity() : Component
- cons : PCBItemSets
- contains() : AShape, CircleEx, IsoRectEx, Net, PolygonEx, TriangleEx, Via, WideSegment_25
- contains2D() : Object
- contains3D() : Object
- Coords() : UniformGrid25
- copper_index : dsn::Layer
- copper_layers : dsn::Structure
- copyFrom() : NavGrid, NavPoint, Object
- copyto() : py::NPArray< T >
- CostMap : UserAgent
- Count : GridDirection
- count() : IndexRange, py::NPArray< T >
- countActions() : Agent
- countIntersections() : Path
- countX() : IndexRange
- countXY() : IndexRange
- countY() : IndexRange
- countZ() : IndexRange
- create() : Agent, IUIApplication, NetTopology, ObjectsBVH, PCBFactory, Policy, py::NPArray< T >, RewardFunction, rewards::RouteLength, StateRepresentation
- createInstance() : GLWidget
- cutLayers() : Via
- CYAN : Color